@@ -123,6 +123,7 @@ enum {
   SPVM_OP_C_CODE_STRING,
   SPVM_OP_C_CODE_WEAKEN,
   SPVM_OP_C_CODE_WEAKEN_FIELD,
+  SPVM_OP_C_CODE_SPECIAL_ASSIGN,
 };
 
 extern const char* const SPVM_OP_C_CODE_NAMES[];
@@ -153,11 +154,27 @@ enum {
   SPVM_OP_C_FLAG_ASSIGN_TMP_VAR = 1
 };
 
+enum {
+  // Special assign flag
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_ADD,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_SUBTRACT,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_MULTIPLY,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_DIVIDE,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_REMAINDER,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_LEFT_SHIFT,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_RIGHT_SHIFT,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_RIGHT_SHIFT_UNSIGNED,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_BIT_XOR,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_BIT_OR,
+  SPVM_OP_C_FLAG_SPECIAL_ASSIGN_BIT_AND,
+};
+
 enum {
   // CALL_FIELD flag
   SPVM_OP_C_FLAG_CALL_FIELD_WEAKEN = 1
 };
 
+
 /* Binary operation */
 struct SPVM_op {
   SPVM_OP* first;
